LHCb Software configuration Database 2 Clients
====================================
|pipeline status| |coverage report|


Neo4j database used to store the dependencies of the LHCb software projects.


.. |pipeline status| image:: https://gitlab.cern.ch/lhcb-core/LbSoftConfDb2Clients/badges/master/pipeline.svg
                     :target: https://gitlab.cern.ch/lhcb-core/LbSoftConfDb2Clients/commits/master
.. |coverage report| image:: https://gitlab.cern.ch/lhcb-core/LbSoftConfDb2Clients/badges/master/coverage.svg
                     :target: https://gitlab.cern.ch/lhcb-core/LbSoftConfDb2Clients/commits/master
